@@ -12,17 +12,19 @@ options::options(QWidget *parent) :    QWidget(parent)
     QScrollArea *area=new QScrollArea(this);
     QWidget *wgt=new QWidget(area);
     wgt->show();
+    wgt->setMinimumHeight(640);
+    wgt->setMinimumWidth(780);
     area->setWidget(wgt);
     lay2->addWidget(area);
     QVBoxLayout *lay=new QVBoxLayout(wgt);
-    a=new QCheckBox("Accelometer",wgt);
-    b=new QComboBox(wgt); b->addItems(QStringList()<<"no scale"<<"double scale"<<"triple scale"<<"fullscreen");
-    c=new QCheckBox("No sound",wgt);
-    d=new QComboBox(wgt);d->addItems(QStringList()<<"Off"<<"Auto"<<"Manual");
-    e=new QSpinBox(wgt);e->setRange(0,15);
-    f=new QComboBox(wgt);f->addItem("uniform");f->addItem("random");
-    g=new QComboBox(wgt);g->addItems(QStringList()<<"3072"<<"4096"<< "5120"<< "6144"<< "7168"<<"8192"<< "9216"<< "10240"<< "11264"<< "12288");
-
+    a=new QCheckBox("Accelometer",this);
+    b=new QComboBox(this); b->addItems(QStringList()<<"no scale"<<"double scale"<<"triple scale"<<"fullscreen");
+    c=new QCheckBox("No sound",this);
+    d=new QComboBox(this);d->addItems(QStringList()<<"Off"<<"Auto"<<"Manual");
+    e=new QSpinBox(this);e->setRange(0,15);
+    f=new QComboBox(this);f->addItem("uniform");f->addItem("random");
+    g=new QComboBox(this);g->addItems(QStringList()<<"3072"<<"4096"<< "5120"<< "6144"<< "7168"<<"8192"<< "9216"<< "10240"<< "11264"<< "12288");
+    a->show();b->show();c->show();d->show();e->show();f->show();g->show();
     lay->addWidget(a);
     lay->addWidget(b);
     lay->addWidget(c);
